pub async fn list_journal_commands(
__arg0: State<AdminState>,
__arg1: Query<JournalQuery>,
) -> impl IntoResponseExpand description
GET /monitoring/engine/journal/commands - List recent durable journal entries
Returns the last N journal command records showing what commands were durably persisted to the database. Unlike in-memory command traces, these survive restarts and provide idempotency guarantees.
Authentication: Requires X-Admin-Key header (performance protection).